@@ -10,7 +10,6 @@
 #define _CHAN_H
 
 #include "zncconfig.h"
-#include "FileUtils.h"
 #include "Nick.h"
 #include "ZNCString.h"
 #include <map>
@@ -24,6 +23,8 @@ using std::set;
 // Forward Declarations
 class CUser;
 class CClient;
+class CConfig;
+class CFile;
 // !Forward Declarations
 
 class CChan {
@@ -51,7 +52,7 @@ public:
 		M_Except     = 'e'
 	} EModes;
 
-	CChan(const CString& sName, CUser* pUser, bool bInConfig);
+	CChan(const CString& sName, CUser* pUser, bool bInConfig, CConfig *pConfig = NULL);
 	~CChan();
 
 	void Reset();
@@ -87,6 +88,7 @@ public:
 	// Buffer
 	int AddBuffer(const CString& sLine);
 	void ClearBuffer();
+	void TrimBuffer(const unsigned int uMax);
 	void SendBuffer(CClient* pClient);
 	// !Buffer
 
@@ -98,6 +100,7 @@ public:
 	// !wrappers
 
 	// Setters
+	void SetModeKnown(bool b) { m_bModeKnown = b; }
 	void SetIsOn(bool b) { m_bIsOn = b; if (!b) { Reset(); } }
 	void SetKey(const CString& s) { m_sKey = s; }
 	void SetTopic(const CString& s) { m_sTopic = s; }
@@ -116,6 +119,7 @@ public:
 	// !Setters
 
 	// Getters
+	bool IsModeKnown() const { return m_bModeKnown; }
 	bool HasMode(unsigned char uMode) const;
 	CString GetOptions() const;
 	CString GetModeArg(unsigned char uMode) const;
@@ -160,6 +164,7 @@ protected:
 	unsigned int                 m_uBufferCount;
 	vector<CString>              m_vsBuffer;
 
+	bool                         m_bModeKnown;
 	map<unsigned char, CString>  m_musModes;
 };
 
