@@ -151,4 +151,8 @@ public:
 	}
 };
 
+template<> void TModInfo<CCryptMod>(CModInfo& Info) {
+	Info.SetWikiPage("crypt");
+}
+
 MODULEDEFS(CCryptMod, "Encryption for channel/private messages")
